Common event types and framework for Sonos UPnP events
This module provides the core event infrastructure that is service-agnostic. Service-specific event types are defined in their respective service modules.
Structs
- Enriched
Event - An enriched event that includes context and source information
- Event
Parser Registry - Registry for service-specific event parsers
Enums
- Event
Source - Source of an event - indicates whether it came from UPnP events or polling
Traits
- Event
Parser - Trait for parsing service-specific events from XML
- Event
Parser Dyn - Dynamic trait for type-erased event parsing
Functions
- extract_
xml_ value - Helper function to extract values from XML using basic text matching This is used as a fallback when proper parsers are not available